@@ -1,4 +1,4 @@
-plot.mfp <- function (x, var=NULL, ref.zero=TRUE, ask=TRUE, ...) 
+plot.mfp <- function (x, var=NULL, ref.zero=TRUE, what="all", ask=TRUE, ...) 
 {
     if (!inherits(x, "mfp")) 
         stop("This is not an mfp object")
@@ -24,20 +24,23 @@ plot.mfp <- function (x, var=NULL, ref.zero=TRUE, ask=TRUE, ...)
             tmpx <- eval(as.name(namex))
         }
         ord <- order(tmpx)
-    	tmpx <- sort(tmpx)
+    	tmpx <- tmpx[ord]
 #
         npwrsx <- sum(is.finite(x$powers[ip, ]))
         if (npwrsx > 0) {
             if (ip > 1) 
                 posx <- int + sum(is.finite(x$powers[seq(ip-1), ])) + seq(npwrsx)
             else posx <- int + seq(npwrsx)
-			xtmp <- t(matrix(tmpx,ncol=length(tmpx),nrow=npwrsx,byrow=TRUE)^x$powers[ip,1:npwrsx])
-            fx <- xtmp %*% x$coef[posx]
-            if (ref.zero) {
-             xcenter <- mean(tmpx, na.rm=TRUE)^x$powers[ip,1:npwrsx]
-             ycenter <- as.vector(xcenter %*% x$coef[posx])
-             fx <- fx - ycenter
-            }
+browser()
+#			xtmp <- t(matrix(tmpx,ncol=length(tmpx),nrow=npwrsx,byrow=TRUE)^x$powers[ip,1:npwrsx])
+            px <- predict(x, type="link", se.fit=TRUE)
+			fx <- px$fit
+			conf.int <- 0.95
+			zcrit <- if (length(idf <- x$df.residual)) 
+				qt((1 + conf.int)/2, idf)
+			else qnorm((1 + conf.int)/2)
+#	actually only for linearily related covariates 
+			lower <- fx-zcrit*px$se.fit; upper <- fx-zcrit*px$se.fit
         }
 
 # Plots
@@ -48,11 +51,12 @@ plot.mfp <- function (x, var=NULL, ref.zero=TRUE, ask=TRUE, ...)
 #
         if (int) {                      # generalized linear model
             if (npwrsx > 0) {
-                plot(tmpx, fx, xlab = namex, ylab = paste("Linear predictor", 
-                  sep = ""), type = "l", ...)
+				limits <- range(c(lower,upper))
+                plot(tmpx, fx, xlab = namex, ylab = paste("Linear predictor", sep = ""), type = "l", ylim=limits, ...)
+                lines(tmpx, lower, lty=2); lines(tmpx, upper, lty=2)
                 pres <- x$residuals[ord] + fx
-                plot(tmpx, pres, xlab = namex, ylab = "Partial residuals", 
-                  ...)
+                points(tmpx, pres)
+#                plot(tmpx, pres, xlab = namex, ylab = "Partial residuals", ...)
 				ok <- is.finite(tmpx) & is.finite(pres)
                 fl <- lowess(tmpx[ok], pres[ok], iter = 0)
                 lines(fl$x, fl$y, lwd = 1, col = "red")
@@ -70,11 +74,13 @@ plot.mfp <- function (x, var=NULL, ref.zero=TRUE, ask=TRUE, ...)
             lines(fl$x, fl$y, lwd = 1, col = "red")
 # Fitted function
             if (npwrsx > 0) {
+				limits <- range(c(lower,upper))
                 plot(tmpx, fx, xlab = namex, ylab = "Linear predictor", 
-                  type = "l", ...)
+                  type = "l", ylim=limits, ...)
+				lines(tmpx, lower, lty=2); lines(tmpx, upper, lty=2)
                 pres <- x$residuals[ord] + fx
-                plot(tmpx, pres, xlab = namex, ylab = "Partial residuals", 
-                  ...)
+                points(tmpx, pres)
+#                plot(tmpx, pres, xlab = namex, ylab = "Partial residuals", ...)
 				ok <- is.finite(tmpx) & is.finite(pres)
                 fl <- lowess(tmpx[ok], pres[ok], iter = 0)
                 lines(fl$x, fl$y, lwd = 1, col = "red")
